Bloom Filter Trie: Globals

Bloom Filter Trie

- Main Page
- Data Structures
- Files

- File List
- Globals

- All
- Functions
- Typedefs
- Macros

- b
- c
- d
- e
- f
- g
- i
- l
- n
- p
- q
- s
- u
- v
- w

### - b -

- BFS() : snippets.h
- BFS_subgraph() : snippets.h

### - c -

- cdbg_traversal() : snippets.h
- create_BFT_annotation() : bft.h
- create_cdbg() : bft.h
- create_empty_kmer() : bft.h
- create_kmer() : bft.h

### - d -

- DFS() : snippets.h
- DFS_subgraph() : snippets.h

### - e -

- extract_core_kmers() : snippets.h
- extract_core_simple_paths() : snippets.h
- extract_dispensable_kmers() : snippets.h
- extract_kmers_to_disk() : bft.h
- extract_pangenome_kmers_to_disk() : snippets.h
- extract_simple_core_paths_to_disk() : snippets.h
- extract_simple_paths() : snippets.h
- extract_simple_paths_to_disk() : snippets.h
- extract_singleton_kmers() : snippets.h

### - f -

- free_BFT_annotation() : bft.h
- free_BFT_kmer() : bft.h
- free_BFT_kmer_content() : bft.h
- free_cdbg() : bft.h

### - g -

- get_annotation() : bft.h
- get_count_id_genomes() : bft.h
- get_flag_kmer() : bft.h
- get_kmer() : bft.h
- get_list_id_genomes() : bft.h
- get_nb_connected_component() : snippets.h
- get_neighbors() : bft.h
- get_predecessors() : bft.h
- get_successors() : bft.h

### - i -

- insert_genomes_from_files() : bft.h
- insert_kmers_last_genome() : bft.h
- insert_kmers_new_genome() : bft.h
- intersection_annotations() : bft.h
- is_in_subgraph() : snippets.h
- is_kmer_in_cdbg() : bft.h
- iterate_over_kmers() : bft.h

### - l -

- load_BFT() : bft.h

### - n -

- nb_connected_components() : snippets.h

### - p -

- prefix_matching() : bft.h
- presence_genome() : bft.h

### - q -

- query_sequence() : bft.h

### - s -

- set_flag_kmer() : bft.h
- set_marking() : bft.h
- set_neighbors_traversal() : bft.h
- sym_difference_annotations() : bft.h

### - u -

- union_annotations() : bft.h
- unset_marking() : bft.h
- unset_neighbors_traversal() : bft.h

### - v -

- v_iterate_over_kmers() : bft.h

### - w -

- write_BFT() : bft.h
- write_kmer_ascii_to_disk() : bft.h
- write_kmer_comp_to_disk() : bft.h